==> duiba-rcmd-alg-1.0.2-20180319.065442-2-sources.jar: com/duiba/rcmd/material/Materialnfo.java <==
package com.duiba.rcmd.material;

import java.util.List;
import java.util.Map;

public class Materialnfo {
    long materialId; //素材id
    long appId; //appid
    double alpha; //模型参数
    double beta;//模型参数
    double reward;//模型参数
    double count;//模型参数
    List<Map<Long, Long>> hour_clicks; //每个小时的统计点击
    List<Map<Long, Long>> hour_exposures;//每个小时的统计曝光
    List<Long> click;//最近一个小时的点击，每分钟 
    List<Long> exposure;//最近一个小时的曝光，每分钟
    double his_click; //模型参数
    double his_exposures; //模型参数


    //SET METHOD
    public void setMaterialnfo(long materialId) {
        this.materialId = materialId;
    }

    public void setAppId(long appId) {
        this.appId = appId;
    }

    public void setAlpha(double alpha) {
        this.alpha = alpha;
    }

    public void setBeta(double beta) {
        this.beta = beta;
    }

    public void setReword(double reward) {
        this.reward = reward;
    }

    public void setCount(double count) {
        this.count = count;
    }

    public void setHourClicks(List<Map<Long, Long>> hour_clicks) {
        this.hour_clicks = hour_clicks;
    }

    public void setHourExposures(List<Map<Long, Long>> hour_exposures) {
        this.hour_exposures = hour_exposures;
    }

    public void setClick(List<Long> click) {
        this.click = click;
    }

    public void setExposure(List<Long> exposure) {
        this.exposure = exposure;
    }

    public void setHisClick(double his_click) {
        this.his_click = his_click;
    }

    public void setHisExposures(double his_exposures) {
        this.his_exposures = his_exposures;
    }


    //GET METHOD
    public long getMaterialnfo() {
        return this.materialId;
    }

    public long getAppId() {
        return appId;
    }

    public double getAlpha() {
        return alpha;
    }

    public double getBeta() {
        return beta;
    }

    public double getReward() {
        return reward;
    }

    public double getCount() {
        return count;
    }

    public List<Map<Long, Long>> getHourClicks() {
        return this.hour_clicks ;
    }

    public List<Map<Long, Long>> getHourExposures() {
        return this.hour_exposures ;
    }

    public List<Long> getClick() {
        return this.click;
    }

    public List<Long> setExposure() {
        return this.exposure;
    }

    public double getHisClick() {
        return this.his_click ;
    }

    public double getHisExposures() {
        return this.his_exposures ;
    }


}

==> duiba-rcmd-alg-1.0.3-20180321.095921-1-sources.jar: com/duiba/rcmd/material/Materialnfo.java <==
package com.duiba.rcmd.material;

import java.util.List;
import java.util.Map;

public class Materialnfo {
    long materialId; //素材id
    long appId; //appid
    double alpha; //模型参数
    double beta;//模型参数
    double reward;//模型参数
    double count;//模型参数
    List<Map<Long, Long>> hour_clicks; //每个小时的统计点击
    List<Map<Long, Long>> hour_exposures;//每个小时的统计曝光
    List<Long> click;//最近一个小时的点击，每分钟 
    List<Long> exposure;//最近一个小时的曝光，每分钟
    double his_click; //模型参数
    double his_exposures; //模型参数


    //SET METHOD
    public void setMaterialnfo(long materialId) {
        this.materialId = materialId;
    }

    public void setAppId(long appId) {
        this.appId = appId;
    }

    public void setAlpha(double alpha) {
        this.alpha = alpha;
    }

    public void setBeta(double beta) {
        this.beta = beta;
    }

    public void setReword(double reward) {
        this.reward = reward;
    }

    public void setCount(double count) {
        this.count = count;
    }

    public void setHourClicks(List<Map<Long, Long>> hour_clicks) {
        this.hour_clicks = hour_clicks;
    }

    public void setHourExposures(List<Map<Long, Long>> hour_exposures) {
        this.hour_exposures = hour_exposures;
    }

    public void setClick(List<Long> click) {
        this.click = click;
    }

    public void setExposure(List<Long> exposure) {
        this.exposure = exposure;
    }

    public void setHisClick(double his_click) {
        this.his_click = his_click;
    }

    public void setHisExposures(double his_exposures) {
        this.his_exposures = his_exposures;
    }


    //GET METHOD
    public long getMaterialnfo() {
        return this.materialId;
    }

    public long getAppId() {
        return appId;
    }

    public double getAlpha() {
        return alpha;
    }

    public double getBeta() {
        return beta;
    }

    public double getReward() {
        return reward;
    }

    public double getCount() {
        return count;
    }

    public List<Map<Long, Long>> getHourClicks() {
        return this.hour_clicks ;
    }

    public List<Map<Long, Long>> getHourExposures() {
        return this.hour_exposures ;
    }

    public List<Long> getClick() {
        return this.click;
    }

    public List<Long> getExposure() {
        return this.exposure;
    }

    public double getHisClick() {
        return this.his_click ;
    }

    public double getHisExposures() {
        return this.his_exposures ;
    }


}
